@@ -31,7 +31,7 @@
 #include "gst-conf.h"
 
 #ifdef HAVE_POLKIT
-#include "gst-polkit-button.h"
+#include <polkitgtk/polkitgtk.h>
 #endif
 
 #define GST_DIALOG_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), GST_TYPE_DIALOG, GstDialogPrivate))
@@ -88,7 +88,7 @@ static void     gst_dialog_realize      (GtkWidget   *widget);
 static void     gst_dialog_set_cursor   (GstDialog     *dialog,
 					 GdkCursorType  cursor_type);
 
-static void             gst_dialog_unlock                (GstDialog *dialog);
+static void             gst_dialog_lock_changed          (GstDialog *dialog);
 static GstWidgetPolicy *gst_dialog_get_policy_for_widget (GtkWidget *widget);
 
 enum {
@@ -99,7 +99,7 @@ enum {
 };
 
 enum {
-	UNLOCKED,
+	LOCK_CHANGED,
 	LAST_SIGNAL
 };
 
@@ -146,11 +146,11 @@ gst_dialog_class_init (GstDialogClass *class)
 							      NULL,
 							      G_PARAM_WRITABLE | G_PARAM_CONSTRUCT_ONLY));
 
-	signals [UNLOCKED] =
-		g_signal_new ("unlocked",
+	signals [LOCK_CHANGED] =
+		g_signal_new ("lock-changed",
 			      G_OBJECT_CLASS_TYPE (object_class),
 			      G_SIGNAL_RUN_LAST,
-			      G_STRUCT_OFFSET (GstDialogClass, unlocked),
+			      G_STRUCT_OFFSET (GstDialogClass, lock_changed),
 			      NULL, NULL,
 			      g_cclosure_marshal_VOID__VOID,
 			      G_TYPE_NONE, 0);
@@ -174,22 +174,6 @@ gst_dialog_init (GstDialog *dialog)
 	priv->modified = FALSE;
 
 	priv->policy_widgets = NULL;
-
-#ifdef HAVE_POLKIT
-	priv->polkit_button = gst_polkit_button_new (NULL, _("_Unlock"));
-	gtk_widget_show (priv->polkit_button);
-
-	gtk_dialog_add_action_widget (GTK_DIALOG (dialog),
-				      priv->polkit_button, GTK_RESPONSE_NONE);
-
-	g_signal_connect_swapped (priv->polkit_button, "changed",
-				  G_CALLBACK (gst_dialog_unlock), dialog);
-#endif
-
-	gtk_dialog_add_buttons (GTK_DIALOG (dialog),
-				GTK_STOCK_HELP, GTK_RESPONSE_HELP,
-				GTK_STOCK_CLOSE, GTK_RESPONSE_CLOSE,
-				NULL);
 }
 
 static GObject*
@@ -230,7 +214,7 @@ gst_dialog_constructor (GType                  type,
 			exit (-1);
 		}
 
-		gtk_widget_ref (priv->child);
+		g_object_ref (priv->child);
 		gtk_container_remove (GTK_CONTAINER (priv->child->parent), priv->child);
 		gtk_container_add (GTK_CONTAINER (GTK_DIALOG (dialog)->vbox), priv->child);
 
@@ -240,12 +224,25 @@ gst_dialog_constructor (GType                  type,
 #ifdef HAVE_POLKIT
 	if (priv->tool) {
 		const gchar *action;
+		GtkWidget *action_area;
 
 		action = oobs_session_get_authentication_action (priv->tool->session);
-		gst_polkit_button_set_action (GST_POLKIT_BUTTON (priv->polkit_button), action);
+		priv->polkit_button = polkit_lock_button_new (action);
+		gtk_widget_show (priv->polkit_button);
+
+		action_area = gtk_dialog_get_action_area (GTK_DIALOG (dialog));
+		gtk_box_pack_start (GTK_BOX (action_area), priv->polkit_button, TRUE, TRUE, 0);
+
+		g_signal_connect_swapped (priv->polkit_button, "changed",
+					  G_CALLBACK (gst_dialog_lock_changed), dialog);
 	}
 #endif
 
+	gtk_dialog_add_buttons (GTK_DIALOG (dialog),
+				GTK_STOCK_HELP, GTK_RESPONSE_HELP,
+				GTK_STOCK_CLOSE, GTK_RESPONSE_CLOSE,
+				NULL);
+
 	if (priv->title)
 		gtk_window_set_title (GTK_WINDOW (dialog), priv->title);
 
@@ -372,7 +369,7 @@ gst_dialog_get_widget (GstDialog *dialog, const char *widget)
 }
 
 static void
-gst_dialog_unlock (GstDialog *dialog)
+gst_dialog_lock_changed (GstDialog *dialog)
 {
 	GstDialogPrivate *priv;
 	GSList *list;
@@ -384,11 +381,15 @@ gst_dialog_unlock (GstDialog *dialog)
 		GstWidgetPolicy *policy;
 
 		widget = list->data;
-		policy = gst_dialog_get_policy_for_widget (widget);
-		gtk_widget_set_sensitive (widget, policy->was_sensitive);
+		if (gst_dialog_is_authenticated (dialog)) {
+			policy = gst_dialog_get_policy_for_widget (widget);
+			gtk_widget_set_sensitive (widget, policy->was_sensitive);
+		}
+		else
+			gtk_widget_set_sensitive (widget, FALSE);
 	}
 
-	g_signal_emit (dialog, signals [UNLOCKED], 0);
+	g_signal_emit (dialog, signals [LOCK_CHANGED], 0);
 }
 
 static void
@@ -634,7 +635,9 @@ gst_dialog_is_authenticated (GstDialog *dialog)
 
 	priv = GST_DIALOG_GET_PRIVATE (dialog);
 
-	return gst_polkit_button_get_authenticated (GST_POLKIT_BUTTON (priv->polkit_button));
+	return (polkit_lock_button_get_is_authorized (POLKIT_LOCK_BUTTON (priv->polkit_button)) ||
+		(polkit_lock_button_get_can_obtain (POLKIT_LOCK_BUTTON (priv->polkit_button)) &&
+		!polkit_lock_button_get_is_visible (POLKIT_LOCK_BUTTON (priv->polkit_button))));
 #else
 	return TRUE;
 #endif
@@ -650,6 +653,19 @@ gst_dialog_get_editing (GstDialog *dialog)
 	return (priv->edit_dialogs != NULL);
 }
 
+GtkWidget *
+gst_dialog_get_topmost_edit_dialog (GstDialog *dialog)
+{
+	GstDialogPrivate *priv;
+
+	priv = GST_DIALOG_GET_PRIVATE (dialog);
+
+	if (!priv->edit_dialogs)
+		return NULL;
+
+	return GTK_WIDGET (priv->edit_dialogs->data);
+}
+
 void
 gst_dialog_add_edit_dialog (GstDialog *dialog,
 			    GtkWidget *edit_dialog)
