@@ -99,6 +99,9 @@ get_ntp_service (GstTimeTool *tool)
 	gboolean valid;
 	GstServiceRole role;
 
+	/* Be sure we take into account newly installed NTP support */
+	oobs_object_update (OOBS_OBJECT (tool->services_config));
+
 	list = oobs_services_config_get_services (OOBS_SERVICES_CONFIG (tool->services_config));
 	valid = oobs_list_get_iter_first (list, &iter);
 
@@ -348,6 +351,7 @@ init_timezone (GstTimeTool *time_tool)
 {
 	GstTool *tool = GST_TOOL (time_tool);
 	GtkWidget *w;
+	GtkCellRenderer *cell;
 	GPtrArray *locs;
 	GList *combo_locs = NULL;
 	int i;
@@ -360,6 +364,9 @@ init_timezone (GstTimeTool *time_tool)
 	gtk_widget_show (GTK_WIDGET (time_tool->tzmap->map));
 
 	w = gst_dialog_get_widget (tool->main_dialog, "location_combo");
+	cell = gtk_cell_renderer_text_new ();
+	gtk_cell_layout_pack_start (GTK_CELL_LAYOUT (w), cell, TRUE);
+	gtk_cell_layout_set_attributes (GTK_CELL_LAYOUT (w), cell, "text", 0, NULL);
 	locs = tz_get_locations (e_tz_map_get_tz_db (time_tool->tzmap));
 
 	for (i = 0; i < locs->len; i++)
