@@ -294,14 +294,19 @@ on_user_new_clicked (GtkButton *button, gpointer user_data)
 	if (response == GTK_RESPONSE_OK) {
 		user = user_settings_dialog_get_data (dialog);
 
+		if (!user) /* Means an error has already occurred and been displayed, stop here */
+			return;
+
 		config = OOBS_USERS_CONFIG (GST_USERS_TOOL (tool)->users_config);
 		users_list = oobs_users_config_get_users (config);
 		oobs_list_append (users_list, &list_iter);
 		oobs_list_set (users_list, &list_iter, user);
 
-		users_table_add_user (user, &list_iter);
-		gst_tool_commit (tool, GST_USERS_TOOL (tool)->users_config);
-		gst_tool_commit (tool, GST_USERS_TOOL (tool)->groups_config);
+		/* Avoid showing the new user or trying to commit group changes if the user has not been created */
+		if (gst_tool_commit (tool, GST_USERS_TOOL (tool)->users_config) == OOBS_RESULT_OK) {
+			gst_tool_commit (tool, GST_USERS_TOOL (tool)->groups_config);
+			users_table_add_user (user, &list_iter);
+		}
 	}
 }
 
@@ -339,12 +344,16 @@ on_user_settings_clicked (GtkButton *button, gpointer user_data)
 		gtk_tree_model_filter_convert_iter_to_child_iter (GTK_TREE_MODEL_FILTER (model),
 								  &filter_iter, &iter);
 		user = user_settings_dialog_get_data (dialog);
-		users_table_set_user (user, list_iter, &filter_iter);
+
+		if (!user) /* Means an error has already occurred and been displayed, stop here */
+			return;
 
 		if (gst_dialog_is_authenticated (tool->main_dialog)) {
 			/* change users/groups configuration */
-			gst_tool_commit (tool, GST_USERS_TOOL (tool)->users_config);
-			gst_tool_commit (tool, GST_USERS_TOOL (tool)->groups_config);
+			if (gst_tool_commit (tool, GST_USERS_TOOL (tool)->users_config) == OOBS_RESULT_OK) {
+				gst_tool_commit (tool, GST_USERS_TOOL (tool)->groups_config);
+				users_table_set_user (user, list_iter, &filter_iter);
+			}
 #ifdef HAVE_POLKIT
 		/* With PolicyKit1, we don't have to check for authorizations: just try to commit,
 		 * the backend will trigger authentication if possible, or fail */
@@ -352,8 +361,9 @@ on_user_settings_clicked (GtkButton *button, gpointer user_data)
 			OobsObject *object = GST_USERS_TOOL (tool)->self_config;
 
 			/* change self, only if it is the modified user */
-			if (user == oobs_self_config_get_user (OOBS_SELF_CONFIG (object))) {
-				gst_tool_commit (tool, GST_USERS_TOOL (tool)->self_config);
+			if (user == oobs_self_config_get_user (OOBS_SELF_CONFIG (object)) &&
+			    gst_tool_commit (tool, GST_USERS_TOOL (tool)->self_config) == OOBS_RESULT_OK) {
+				users_table_set_user (user, list_iter, &filter_iter);
 			}
 #endif
 		}
@@ -425,8 +435,8 @@ on_group_new_clicked (GtkButton *button, gpointer user_data)
 		oobs_list_append (groups_list, &list_iter);
 		oobs_list_set (groups_list, &list_iter, group);
 
-		groups_table_add_group (group, &list_iter);
-		gst_tool_commit (tool, GST_USERS_TOOL (tool)->groups_config);
+		if (gst_tool_commit (tool, GST_USERS_TOOL (tool)->groups_config) == OOBS_RESULT_OK)
+			groups_table_add_group (group, &list_iter);
 	}
 }
 
