@@ -24,43 +24,32 @@
 #ifndef _USERS_TABLE_H
 #define _USERS_TABLE_H
 
-enum {
-	COL_USER_LOGIN,
-	COL_USER_UID,
-	COL_USER_HOME,
-	COL_USER_SHELL,
-	COL_USER_COMMENT,
-	COL_USER_GROUP,
-	COL_USER_POINTER,
+#include "users-tool.h"
 
+enum {
+	COL_USER_FACE,
+	COL_USER_NAME,
+	COL_USER_LOGIN,
+	COL_USER_HOME,
+	COL_USER_ID,
+	COL_USER_MEMBER, /* used in group members dialog */
+	COL_USER_OBJECT,
+	COL_USER_ITER,
+	COL_USER_SENSITIVE,
 	COL_USER_LAST
 };
 
-typedef struct 
-{
-	gchar *name;
-	gboolean advanced_state_showable;
-	gboolean basic_state_showable;
-} TableConfig;
+void	create_users_table	(GstUsersTool *tool);
+void    users_table_clear       (void);
+void    users_table_set_user    (OobsUser     *user,
+				 OobsListIter *list_iter,
+				 GtkTreeIter  *iter);
+void    users_table_add_user    (OobsUser     *user,
+				 OobsListIter *list_iter);
 
-typedef struct UserTreeItem_ UserTreeItem;
-	
-struct UserTreeItem_
-{
-	const gchar *login;
-	guint UID;
-	const gchar *home;
-	const gchar *shell;
-	const gchar *comment;
-	const gchar *group;
-	
-	UserTreeItem *children;
-};
-
-void	create_users_table		(void);
-void	populate_users_table		(void);
-void	update_users_table_complexity	(GstDialogComplexity);
-void	users_table_update_content	(void);
+void    users_table_actions_set_sensitive (gint      table,
+					   gint      count,
+					   OobsUser *user);
 
 #endif /* _USERS_TABLE_H */
 
